@@ -3,4 +3,5 @@ import os
 
 class FileManager(models.Manager):
     def get_from_name(self, name):
-        return self.get(pk=os.path.splitext(os.path.split(name)[1])[0])
+        return self.get(name=name)
+    
\ No newline at end of file
